% Analytical solution for an instataneous solute release from a point source               
%
%--------------------------------------------------------------------------
M = input('Provide solute mass, M:'); %Mass, [g]
ax= input('Provide longitudinal dispersivity, ax:'); % [m]
ay= input('Provide transversal dispersivity, ay:'); % [m]
az= input('Provide transversal dispersivity, az:'); %[m]
Kp= input('Provide partition coefficient, Kp:'); %[cm^3/g]
lambda= input('Provide decay coefficient, l:'); %[d^-1]
De= 0.6e-4; % molecular diffusion coefficient [m^2/d]
n = 0.33; % porosity
vx= 0.081; % seepage velocity, [m/d]
rd= 1.810; % bulk density of the soil [g/cm^3]
R = 1+((rd*Kp)/n); % Retardation factor
vrx = vx/R;
Dx = (ax*vx+De)/R;
Dy = (ay*vx+De)/R;
Dz = (az*vx+De)/R;
z= 0.0; % depth [m]
t = 160; % time [d]
%------------------------create the flow field-----------------------------
xmin = -20; xmax = 30;              % x-axis interval
ymin = -20; ymax = 30;              % y-axis interval
[x,y] = meshgrid (linspace(xmin,xmax,200),linspace(ymin,ymax,200));
%----------------------calculate concentration, c--------------------------
c=zeros(200,200); %
for i=1:200
    for j=1:200
            c(j,i)= (M/(n*8*((pi()*t)^(3/2))*((Dx*Dy*Dz)^0.5)))*...
            exp((-((x(1,i)-vrx*t)^2)/(4*Dx*t))-(y(j,1)^2/(4*Dy*t))-...
            (z^2/(4*Dz*t))-(lambda*t));
    end
end
%----------------------------------output----------------------------------
c=1000*c; % convert to [g/l]
%----------------------------------figure----------------------------------
% Create figure
figure1 = figure;
% Create axes
axes1 = axes('Parent',figure1,'YGrid','on','XGrid','on','Layer','top');
%% Uncomment the following line to preserve the X-limits of the axes
% xlim(axes1,[-20 30]);
%% Uncomment the following line to preserve the Y-limits of the axes
% ylim(axes1,[-20 30]);
box(axes1,'on');
hold(axes1,'all');
% Create contour
contour(x,y,c,'ShowText','on',...
    'DisplayName','Concentration, c [g/l]',...
    'Parent',axes1);
% Create xlabel
xlabel('X (m)');
% Create ylabel
ylabel('Y (m)');
% Create legend
legend1 = legend(axes1,'show');
set(legend1,'Location','Best');